summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/template.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/template.h')
-rw-r--r--umbrello/umbrello/template.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/template.h b/umbrello/umbrello/template.h
index e7558010..6b471207 100644
--- a/umbrello/umbrello/template.h
+++ b/umbrello/umbrello/template.h
@@ -30,20 +30,20 @@ public:
/**
* Sets up a template.
*
* @param tqparent The tqparent of this UMLTemplate (i.e. its concept).
* @param name The name of this UMLTemplate.
* @param id The unique id given to this UMLTemplate.
* @param type The type of this UMLTemplate.
*/
- UMLTemplate(const UMLObject *tqparent, const TQString& name,
+ UMLTemplate(const UMLObject *parent, const TQString& name,
Uml::IDType id = Uml::id_None, const TQString& type = "class");
/**
* Sets up a template.
*
* @param tqparent The tqparent of this UMLTemplate (i.e. its concept).
*/
- UMLTemplate(const UMLObject *tqparent);
+ UMLTemplate(const UMLObject *parent);
/**
* Overloaded '==' operator
@@ -89,7 +89,7 @@ public:
*
* @return Success status.
*/
- bool showPropertiesDialog(TQWidget* tqparent);
+ bool showPropertiesDialog(TQWidget* parent);
/**
* Writes the <UML:TemplateParameter> XMI element.
@@ -30,20 +30,20 @@ public:
* Sets up a template.
*
- * @param tqparent The tqparent of this UMLTemplate (i.e. its concept).
+ * @param parent The parent of this UMLTemplate (i.e. its concept).
* @param name The name of this UMLTemplate.
* @param id The unique id given to this UMLTemplate.
@@ -30,20 +30,20 @@ public:
* Sets up a template.
*
- * @param tqparent The tqparent of this UMLTemplate (i.e. its concept).
+ * @param parent The parent of this UMLTemplate (i.e. its concept).
*/